/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.jcr.contentloader.internal;


/**
 * Interface to provide helpers for the ContentCreator
 *
 */
public interface JcrContentHelper {

	/**
	 * Returns the MIME type from the MimeTypeService for the given name
	 * @param name the name of the file to get the mimeType for  
	 */
	String getMimeType(String name);

	/**
	 * Digest the given password using the configured digest algorithm
	 * 
	 * @param pwd the password to digest
	 * @return digested password
	 * @throws IllegalArgumentException
	 */
    String digestPassword(String pwd) throws IllegalArgumentException;

}
